local love = love
local vector = require "vector"
local Ball = require "Ball"
local table = table
local print = print
local math = math
local setmetatable = setmetatable
local pairs = pairs

local BallsContainer = {}

if setfenv then
   setfenv(1, BallsContainer) -- for 5.1
else
   _ENV = BallsContainer -- for 5.2
end

function BallsContainer:new( o )   
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.balls = o.balls or {}
   return o
end

function BallsContainer:update( dt, platform )
   for key, ball in pairs( self.balls ) do
      ball:update( dt, platform )
      if ball.to_destroy then
        self.balls[key] = nil
      end
   end
end

function BallsContainer:draw()
   for key, val in pairs( self.balls ) do
      val:draw( dt )
   end
end

function BallsContainer:keyreleased( key, scancode, platform )
   if key == ' ' then
      local stuck = {}
      for _, ball in pairs( self.balls ) do
	 if ball.stuck_to_platform then
	    table.insert( stuck, ball )
	 end
	 if #stuck > 0 then
	    stuck[1]:launch_from_platform( platform )
	 end
      end
   elseif key == 'r' then
      for i, ball in pairs( self.balls ) do
	 if i == 1 then
	    ball.position = vector(300,350)
	    ball.speed = vector(300,300)
	 else
	    self.balls[i] = nil
	 end
      end
   end
end

function BallsContainer:mousereleased( x, y, button, istouch, platform )
   if button == 'l' then
      local stuck = {}
      for key, ball in pairs( self.balls ) do
	 if ball.stuck_to_platform then
	    table.insert( stuck, ball )
	 end
	 if #stuck > 0 then
	    stuck[1]:launch_from_platform( platform )
	 end
      end
   end
end

function BallsContainer:add_to_list( new_ball )
  table.insert( self.balls, new_ball )
end

function BallsContainer:react_on_new_ball_bonus()
   local first_ball = self.balls[1]   
   self:add_to_list(
      Ball:new{ image = first_ball.image,
		collisions = { collider = first_ball.collisions.collider },
		position = first_ball.position,
		speed = first_ball.speed:rotated( math.pi / 4 ),
		stuck_to_platform = first_ball.stuck_to_platform } )
end

function BallsContainer:react_on_slow_down_bonus()
   for key, val in pairs( self.balls ) do
      val:react_on_slow_down_bonus()
   end
end

function BallsContainer:react_on_accelerate_bonus()
   for key, val in pairs( self.balls ) do
      val:react_on_accelerate_bonus()
   end
end

function BallsContainer:unstick_all_balls( platform )
   for key, ball in pairs( self.balls ) do
      if ball.stuck_to_platform then
	 ball:launch_from_platform( platform )
      end
   end
end

return BallsContainer
