local vector = require "vector"
local common = require "common"
local HC = require "HC"
local love = love
local setmetatable = setmetatable
local string = string
local print = print
local math = math

local Bonus = {}

if setfenv then
   setfenv(1, Bonus) -- for 5.1
else
   _ENV = Bonus -- for 5.2
end

function Bonus:new (o)
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.name = "bonus"
   o.bonustype = o.bonustype or nil
   if o.bonustype then
      o.to_destroy = false
   else
      o.to_destroy = true
   end
   o.tileset_image = o.tileset_image or nil
   o.quad = o.quad or nil
   local x,y,w,h = o.quad:getViewport()
   o.tilewidth = w
   o.tileheight = h
   o.radius = 14   
   o.position = o.position or vector( 100, 100 )
   o.speed = o.speed or vector( 0 ,  100 )
   o.collisions.shape = o.collisions.collider:circle( o.position.x,
						      o.position.y,
						      o.radius )
   o.collisions.shape.game_object = o
   return o
end

function Bonus:update(dt)
   self:check_destroy()
   if not self.to_destroy then
      self.position = self.position + self.speed * dt
      self.collisions.shape:moveTo( self.position:unpack() )
   end   
end

function Bonus:check_destroy()
   if self.to_destroy then
      self.collisions.collider:remove( self.collisions.shape )
      self.collisions.shape = nil
      self.bonustype = nil
   end
end

function Bonus:draw()
   if self.bonustype then
      love.graphics.draw( self.tileset_image,
			  self.quad, 
			  self.position.x - self.tilewidth/2,
			  self.position.y - self.tileheight/2 )
   end
end

function Bonus:react_on_platform_collision( shape, separating_vector )
   self.to_destroy = true
end

function Bonus:random_bonustype()
   -- once in 5 levels (~400 blocks): L or N
   -- once in 10 blocks - any others with roughly equal prob
   local bonustype
   local common_bonuses = {
      'bonus_red',
      'bonus_blue',
      'bonus_orange',
      'bonus_yellow',
      'bonus_purple',
      'bonus_green' }
   local prob = math.random( 402 )
   if prob == 402 then
      bonustype = 'bonus_grey'
   elseif prob == 401 then
      bonustype = 'bonus_white'
   elseif prob > 360 then
      bonustype = common_bonuses[ math.ceil( (prob - 360)/7 ) ]
   else
      bonustype = nil
   end
   return bonustype
end

return Bonus
