local love = love
local print = print
local vector = require "vector"
local Bonus = require "Bonus"
local table = table
local setmetatable = setmetatable
local pairs = pairs

local BonusesContainer = {}

if setfenv then
   setfenv(1, BonusesContainer) -- for 5.1
else
   _ENV = BonusesContainer -- for 5.2
end

function BonusesContainer:new (o)   
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.bonuses = o.bonuses or {}
   return o
end

function BonusesContainer:update(dt)
   for key, val in pairs( self.bonuses ) do
      val:update( dt )
      if val.to_destroy then
        self.bonuses[key] = nil
      end
   end
end

function BonusesContainer:draw()
   for key, val in pairs( self.bonuses ) do
      val:draw(dt)
   end
end

function BonusesContainer:add_to_list( new_bonus )
  table.insert( self.bonuses, new_bonus )
end

return BonusesContainer
