local vector = require "vector"
local common = require "common"
local Bonus = require "Bonus"
local HC = require "HC"
local love = love
local setmetatable = setmetatable
local string = string
local print = print

local Brick = {}

if setfenv then
   setfenv(1, Brick) -- for 5.1
else
   _ENV = Brick -- for 5.2
end

function Brick:new( o )
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.name = "brick"
   o.bricktype = o.bricktype or nil
   if o.bricktype then
      o.to_destroy = false
   else
      o.to_destroy = true
   end
   o.tileset_image = o.tileset_image or nil
   o.quad = o.quad or nil
   o.human_readable_type_to_quad = o.human_readable_type_to_quad or nil
   local x,y,tilewidth,tileheight = o.quad:getViewport()
   o.width = tilewidth
   o.height = tileheight
   o.position = o.position or vector(600, 500)
   if o.bricktype then
      o.collisions.shape = o.collisions.collider:rectangle(
	 o.position.x + 2,
	 o.position.y + 2,
	 tilewidth - 4,
	 tileheight - 4 )
      o.collisions.shape.game_object = o
   end
   o.bonustype = o.bonustype or nil
   o.bonusquad = o.bonusquad or nil
   return o
end

function Brick:update(dt)
   self:check_destroy()
end

function Brick:check_destroy()
   if self.to_destroy then      
      self.bricktype = nil
      self.collisions.collider:remove( self.collisions.shape )
      self.collisions.shape = nil
      self:check_spawn_bonus() 
   end
end

function Brick:check_spawn_bonus()
   if self.bonustype == 'random_bonus' then
      self.bonustype = Bonus:random_bonustype()
   end
   if self.bonustype then
      new_bonus = Bonus:new{
	 collisions = { collider = self.collisions.collider },
	 bonustype = self.bonustype,
	 tileset_image = self.tileset_image,
	 quad = self.human_readable_type_to_quad( self.bonustype ),
	 position = vector( self.position.x + self.width/2,
			    self.position.y + self.height / 2 ) }
      self.bonus_list:add_to_list( new_bonus )
   end
end


function Brick:draw()
   if self.bricktype then
      love.graphics.draw( self.tileset_image,
      			  self.quad, 
      			  self.position.x, self.position.y )
   end
end

function Brick:react_on_ball_collision(	shape, separating_vector )
   if string.match( self.bricktype, 'simple' ) then
	 self:destroy()
   elseif string.match( self.bricktype, "armored_cracked1" ) then
	 self:crack_2_armored()
   elseif string.match( self.bricktype, "armored_cracked2" ) then
      self:crack_3_armored()
   elseif self.bricktype == "brick_heavyarmored" then
      self:hit_heavyarmored()
   elseif string.match( self.bricktype,"armored" ) then
	 self:crack_1_armored()	 
   end
end

function Brick:destroy()
   self.to_destroy = true
end

function Brick:crack_1_armored()
   self.bricktype = self.bricktype .. "_cracked1"                    
   self.quad = self.human_readable_type_to_quad( self.bricktype )
end

function Brick:crack_2_armored()
   self.bricktype = string.gsub( self.bricktype, "cracked1", "cracked2" )
   self.quad = self.human_readable_type_to_quad( self.bricktype )
end

function Brick:crack_3_armored()
   self.to_destroy = true
end

function Brick:hit_heavyarmored()
end

return Brick
