local love = love
local print = print
local vector = require "vector"
local Brick = require "Brick"
local setmetatable = setmetatable
local pairs = pairs

local BricksMap = {}

if setfenv then
   setfenv(1, BricksMap) -- for 5.1
else
   _ENV = BricksMap -- for 5.2
end

function BricksMap:new( o )   
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.map = o.level_map.bricks or nil
   o.tileset_image = love.graphics.newImage( o.level_map.tileset_image_file )
   o.bonus_list = o.bonus_list or {}
   o.brickwidth = 64
   o.brickheight = 32   
   local x_offset, y_offset = 47, 34
   o.offset = vector( x_offset, y_offset )
   o.bricks = {}
   for i = 1, #o.level_map.bricks do
      o.bricks[i] = {}
      for j = 1, #o.level_map.bricks[i] do
	 local bricktype =
	    o.level_map.tileset_description[ o.level_map.bricks[i][j] ]
	 local bonustype
	 if o.level_map.bonuses[i][j] == 0 then
	    bonustype = "random_bonus"
	 else
	    bonustype =
	       o.level_map.tileset_description[ o.level_map.bonuses[i][j] ]
	 end
	 if bricktype then
	    o.bricks[i][j] = Brick:new{
	       bricktype = bricktype,
	       position = o.offset +
		  vector( (j-1)*o.brickwidth, (i-1)*o.brickheight ),
	       tileset_image = o.tileset_image,
	       quad = o.level_map.tileset_id_to_quad(
		  o.level_map.bricks[i][j] ),
	       bonustype = bonustype,	       
	       bonusquad = o.level_map.tileset_id_to_quad(
		  o.level_map.bonuses[i][j] ),
	       bonus_list = o.bonus_list,
	       human_readable_type_to_quad = o.level_map.human_readable_type_to_quad,
	       collisions = { collider = o.collisions.collider } }
	 end
      end
   end   
   return o
end

function BricksMap:update(dt)
   for i, brick_row in pairs( self.bricks ) do
      for j, brick in pairs( brick_row ) do
	 brick:update(dt)
	 if brick.to_destroy then
	    self.bricks[i][j] = nil
	 end
      end
   end   
end

function BricksMap:draw()
   for _, brick_row in pairs( self.bricks ) do
      for _, brick in pairs( brick_row ) do
	 brick:draw()
      end
   end   
end

function BricksMap:no_more_bricks()
   for _, brick_row in pairs( self.bricks ) do
      for _, brick in pairs( brick_row ) do
	 local br_t = brick.bricktype	 
	 if ( ( br_t ~= nil ) and ( br_t ~= "brick_heavyarmored" ) ) then
	    return false
	 end
      end
   end   	
   return true
end	

return BricksMap
