local setmetatable = setmetatable
local string = string
local love = love
local vector = require "vector"
local common = require "common"

local Button = {}

if setfenv then
   setfenv(1, Button)
else
   _ENV = Button
end

function Button:new(o)
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.name = "button"
   o.text = o.text or "hello"
   o.selected = o.selected or false
   o.position = o.position or vector(300, 300)
   o.tileset_image = o.tileset_image or nil
   o.quad = o.quad or nil
   o.width = o.width or 100
   o.height = o.height or 50
   return o
end

function Button:update(dt)
   local mousePos = vector( love.mouse.getPosition() )
   if( self:inside( mousePos ) ) then
      self.selected = true
   else
      self.selected = false
   end
end

function Button:draw()
   if self.selected then
      if self.quad_selected then
	 love.graphics.draw( self.tileset_image,
			     self.quad_selected, 
			     self.position.x, self.position.y )
      else
	 love.graphics.rectangle( 'line',
				  self.position.x,
				  self.position.y,
				  self.width,
				  self.height )
	 local r, g, b, a = love.graphics.getColor()
	 love.graphics.setColor( 255, 0, 0, 100 )
	 love.graphics.print( self.text,
			      self.position.x,
			      self.position.y )
	 love.graphics.setColor( r, g, b, a )
      end
   else
      if self.quad then
	 love.graphics.draw( self.tileset_image,
			     self.quad, 
			     self.position.x, self.position.y )
      else
	 love.graphics.rectangle( 'line',
				  self.position.x,
				  self.position.y,
				  self.width,
				  self.height )
	 love.graphics.print( self.text,
			      self.position.x,
			      self.position.y )	 
      end
   end
end

function Button:mousereleased( x, y, button )
   return self.selected 
end

function Button:inside( pos )
   return
      self.position.x < pos.x and
      pos.x < ( self.position.x + self.width ) and
      self.position.y < pos.y and
      pos.y < ( self.position.y + self.height )
end

return Button
