local love = love
local vector = require "vector"
local HC = require "HC"
local print = print
local setmetatable = setmetatable
local math = math

local Wall = {}
if setfenv then
   setfenv(1, Wall) -- for 5.1
else
   _ENV = Wall -- for 5.2
end

local tileset_width = 800
local tileset_height = 600
local wall_vertical_tile_width = 34
local wall_vertical_tile_height = 96
local wall_vertical_tile_x_pos = 0
local wall_vertical_tile_y_pos = 128
local wall_horizontal_tile_width = 96
local wall_horizontal_tile_height = 26
local wall_horizontal_tile_x_pos = 64
local wall_horizontal_tile_y_pos = 128
local topleft_corner_tile_width = 64
local topleft_corner_tile_height = 64
local topleft_corner_tile_x_pos = 64
local topleft_corner_tile_y_pos = 160
local topright_corner_tile_width = 64
local topright_corner_tile_height = 64
local topright_corner_tile_x_pos = 128
local topright_corner_tile_y_pos = 160


function Wall:new(o)
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.name = "wall"   
   o.image = o.image or nil
   o.vertical_quad = love.graphics.newQuad(
      wall_vertical_tile_x_pos,
      wall_vertical_tile_y_pos,
      wall_vertical_tile_width,
      wall_vertical_tile_height,
      tileset_width, tileset_height )
   o.horizontal_quad = love.graphics.newQuad(
      wall_horizontal_tile_x_pos,
      wall_horizontal_tile_y_pos,
      wall_horizontal_tile_width,
      wall_horizontal_tile_height,
      tileset_width, tileset_height )
   o.topright_corner_quad = love.graphics.newQuad(
      topright_corner_tile_x_pos,
      topright_corner_tile_y_pos,
      topright_corner_tile_width,
      topright_corner_tile_height,
      tileset_width, tileset_height )
   o.topleft_corner_quad = love.graphics.newQuad(
      topleft_corner_tile_x_pos,
      topleft_corner_tile_y_pos,
      topleft_corner_tile_width,
      topleft_corner_tile_height,
      tileset_width, tileset_height )
   o.width = o.width or 50
   o.height = o.height or
      love.graphics.getHeight() + love.graphics.getHeight()/5
   o.position = o.position or vector(0, -love.graphics.getHeight()/5/2)
   o.collisions.shape = o.collisions.collider:rectangle( o.position.x,
							 o.position.y,
							 o.width,
							 o.height )
   o.collisions.shape.game_object = o 
   return o
end

function Wall:update(dt)
   -- 
end

function Wall:draw()
   if ( self.layout == 'top' ) then 
      love.graphics.draw(
      	 self.image,
      	 self.topleft_corner_quad,
      	 self.position.x,
      	 self.position.y )
      love.graphics.draw(
	 self.image,
	 self.topright_corner_quad,			  
	 self.position.x + self.width - topleft_corner_tile_width / 2,
	 self.position.y )
      local repeat_n_times = 4
      for i = 0, repeat_n_times do
   	 shift_x = topleft_corner_tile_width +
	    i * wall_horizontal_tile_width
   	 love.graphics.draw(
	    self.image,
	    self.horizontal_quad,
	    self.position.x + shift_x,
	    self.position.y )
      end
   elseif self.layout == 'left' then 
      local repeat_n_times = math.floor(
	 (self.height - topright_corner_tile_height) /
	    wall_vertical_tile_height )
      for i = 0, repeat_n_times do
	 shift_y = topright_corner_tile_height +
	    i * wall_vertical_tile_height
	 love.graphics.draw( self.image,
			     self.vertical_quad,
			     self.position.x,
			     self.position.y + shift_y )
      end
   elseif self.layout == 'right' then
      local repeat_n_times =
	 math.floor( (self.height - topright_corner_tile_height) /
	       wall_vertical_tile_height )
      for i = 0, repeat_n_times do
	 if not (self.next_level_portal and i == repeat_n_times - 1) then
	    shift_y = topright_corner_tile_height +
	       i * wall_vertical_tile_height
	    love.graphics.draw( self.image,
				self.vertical_quad,
				self.position.x,
				self.position.y + shift_y )
	 end
      end
   end
end


function Wall:react_on_next_level_bonus()
   if self.layout == 'right' then
      self.next_level_portal = true
   end
end

function Wall:next_level_portal_active()
   return (self.layout == 'right') and self.next_level_portal
end


return Wall
