local vector = require "vector"
local Wall = require "Wall"
local love = love
local pairs = pairs
local setmetatable = setmetatable

local WallsContainer = {}
if setfenv then
   setfenv(1, WallsContainer) -- for 5.1
else
   _ENV = WallsContainer -- for 5.2
end

function WallsContainer:new( o )
   o = o or {}
   setmetatable(o, self)
   self.__index = self
   o.image = o.image or nil
   local screenWidth = 800 --love.graphics.getWidth()
   local screenHeight = 600 --love.graphics.getHeight()
   local defaultThickness = 34
   local top_wall_thickness = 26
   local right_border_x_pos = 576
   o.walls = {}
   o.walls.top = Wall:new{
      width = right_border_x_pos,
      height = top_wall_thickness,
      position = vector( 0, 0 ),
      image = o.image,
      layout = "top",
      collisions = { collider = o.collisions.collider } }
   o.walls.bottom = Wall:new{
      width = right_border_x_pos,
      height = defaultThickness,
      position = vector(0, screenHeight - defaultThickness/2 ),
      image = o.image,
      layout = "bottom",
      collisions = { collider = o.collisions.collider } }
   o.walls.left = Wall:new{
      width = defaultThickness,
      height = screenHeight,
      position = vector(0, 0 ),
      image = o.image,
      layout = "left",
      collisions = { collider = o.collisions.collider } }
   o.walls.right = Wall:new{
      width = defaultThickness,
      height = screenHeight,
      position = vector( right_border_x_pos, 0 ),
      image = o.image,
      layout = "right",
      collisions = { collider = o.collisions.collider } }
   return o
end

function WallsContainer:update(dt)
      for k,v in pairs(self.walls) do
         v:update(dt)
      end
end

function WallsContainer:draw()
     for k,v in pairs(self.walls) do
        v:draw()
     end
end

function WallsContainer:react_on_next_level_bonus()
   for k,v in pairs(self.walls) do
      v:react_on_next_level_bonus()
   end   
end

return WallsContainer
