local Gamestate = require "hump/gamestate"
local Button = require "Button"
local vector = require "vector"
local game = game or require "game"
local love = love
local pairs = pairs
local type = type

local gamepaused = gamepaused or {}

if setfenv then
   setfenv(1, gamepaused)
else
   _ENV = gamepaused
end

state_name = "gamepaused"

local button_tileset_width = 640
local button_tileset_height = 320
local button_tile_width = 128
local button_tile_height = 64
local play_button_tile_x_pos = 0
local play_button_tile_y_pos = 0
local quit_button_tile_x_pos = 0
local quit_button_tile_y_pos = 64
local selected_x_shift = 128
local right_border_x_pos = 576
local wall_thickness = 34
local top_wall_thickness = 26

function gamepaused:enter( previous_state, ... )
   game_objects = ...
   buttons_tileset_image = love.graphics.newImage("img/800x600/play_quit.png")
   continue_button = Button:new{
      buttontype = 1,
      text = "Continue",
      position = vector(
	 ( right_border_x_pos + wall_thickness - button_tile_width ) / 2,
	 230 ),
      selected = true,
      tileset_image = buttons_tileset_image,
      width = button_tile_width,
      height = button_tile_height,
      quad = love.graphics.newQuad( play_button_tile_x_pos,
				    play_button_tile_y_pos,
				    button_tile_width,
				    button_tile_height,
				    button_tileset_width,
				    button_tileset_height ),
      quad_selected = love.graphics.newQuad( play_button_tile_x_pos + selected_x_shift,
					     play_button_tile_y_pos,
					     button_tile_width,
					     button_tile_height,
					     button_tileset_width,
					     button_tileset_height )
   }
   quit_button = Button:new {
      buttontype = 2,
      text = "Quit",
      position = vector(
	 ( right_border_x_pos + wall_thickness - button_tile_width ) / 2,
	 340),
      tileset_image = buttons_tileset_image,
      width = button_tile_width,
      height = button_tile_height,
      quad = love.graphics.newQuad( quit_button_tile_x_pos,
				    quit_button_tile_y_pos,
				    button_tile_width,
				    button_tile_height,
				    button_tileset_width,
				    button_tileset_height ),
      quad_selected = love.graphics.newQuad( quit_button_tile_x_pos + selected_x_shift,
					     quit_button_tile_y_pos,
					     button_tile_width,
					     button_tile_height,
					     button_tileset_width,
					     button_tileset_height )
   }
end

function gamepaused:update( dt )
   continue_button:update()
   quit_button:update()
end

function gamepaused:draw()
   -- for _,obj in pairs( game_objects ) do
   --    if type(obj) == "table" and obj.draw then
   -- 	 obj:draw()
   --    end
   -- end
   game_objects.platform:draw()   
   game_objects.balls:draw()
   game_objects.bricksmap:draw()
   game_objects.walls:draw()
   game_objects.bonuses:draw()
   game_objects.side_panel:draw()
   game_objects.life_display:draw()
   game_objects.score_display:draw()

   self:cast_shadow()
   continue_button:draw()
   quit_button:draw()
end

function gamepaused:cast_shadow()
   local screen_height = 600
   local wall_tile_border = 2
   local r, g, b, a = love.graphics.getColor( )
   love.graphics.setColor( 10, 10, 10, 100 )
   love.graphics.rectangle("fill",
			   wall_thickness - wall_tile_border,
			   top_wall_thickness,
			   right_border_x_pos - wall_thickness + wall_tile_border,
			   screen_height - top_wall_thickness )
   love.graphics.setColor( r, g, b, a )      
end

function gamepaused:mousereleased( x, y, button )
   if continue_button:mousereleased( x, y, button ) then
      Gamestate.switch( game, game_objects )
   elseif quit_button:mousereleased( x, y, button ) then
      love.event.quit()
   end   
end

function gamepaused:keyreleased( key, code )
   if key == 'return' then
      Gamestate.switch( game, game_objects )
   elseif  key == 'escape' then
      love.event.quit()
   end    
end

function game:leave()
   game_objects = nil
   buttons_tileset_image = nil
   continue_button = nil
   quit_button = nil
end	

return gamepaused
