local Gamestate = require "hump/gamestate"
local vector = require "vector"
local Button = require "Button"
local game = game or require "game"
local love = love
local require =require

local menu = menu or {}

if setfenv then
   setfenv(1, menu)
else
   _ENV = menu
end

state_name = "menu"

local button_tileset_width = 640
local button_tileset_height = 320
local button_tile_width = 128
local button_tile_height = 64
local play_button_tile_x_pos = 0
local play_button_tile_y_pos = 0
local quit_button_tile_x_pos = 0
local quit_button_tile_y_pos = 64
local selected_x_shift = 128

function menu:enter()
   level_sequence = require "levels/sequence"
   level_number = 1
   buttons_tileset_image = love.graphics.newImage("img/800x600/play_quit.png")
   start_button = Button:new{
      buttontype = 1,
      text = "New game",
      position = vector( (800 - button_tile_width) / 2, 200),
      selected = true,
      tileset_image = buttons_tileset_image,
      width = button_tile_width,
      height = button_tile_height,
      quad = love.graphics.newQuad( play_button_tile_x_pos,
      				    play_button_tile_y_pos,
      				    button_tile_width,
      				    button_tile_height,
      				    button_tileset_width,
      				    button_tileset_height ),
      quad_selected = love.graphics.newQuad( play_button_tile_x_pos + selected_x_shift,
      					     play_button_tile_y_pos,
      					     button_tile_width,
      					     button_tile_height,
      					     button_tileset_width,
      					     button_tileset_height )
   }
   quit_button = Button:new {
      buttontype = 2,
      text = "Quit",
      position = vector( (800 - button_tile_width) / 2, 310),
      tileset_image = buttons_tileset_image,
      width = button_tile_width,
      height = button_tile_height,
      quad = love.graphics.newQuad( quit_button_tile_x_pos,
				    quit_button_tile_y_pos,
				    button_tile_width,
				    button_tile_height,
				    button_tileset_width,
				    button_tileset_height ),
      quad_selected = love.graphics.newQuad( quit_button_tile_x_pos + selected_x_shift,
					     quit_button_tile_y_pos,
					     button_tile_width,
					     button_tile_height,
					     button_tileset_width,
					     button_tileset_height )
   }   
end

function menu:update(dt)
   start_button:update()
   quit_button:update()
end

function menu:draw()
   start_button:draw()
   quit_button:draw()
end

function menu:mousereleased( x, y, button )
   if start_button:mousereleased( x, y, button ) then
      Gamestate.switch( game,
			{ level_sequence = level_sequence,
			  level_number = level_number } )
   elseif quit_button:mousereleased( x, y, button ) then
      love.event.quit()
   end   
end

function menu:keyreleased( key, code )
   if key == 'return' then      
      Gamestate.switch( game,
			{ level_sequence = level_sequence,
			  level_number = level_number } )
   elseif  key == 'escape' then
      love.event.quit()
   end    
end

function menu:leave()
   level_sequence = nil
   level_number = nil
   start_button = nil
   quit_button = nil
   buttons_tileset_image = nil
end

return menu
